Module beamlit.models.token_rate_metric
=======================================

Classes
-------

`TokenRateMetric(model: beamlit.types.Unset | str = <beamlit.types.Unset object>, timestamp: beamlit.types.Unset | str = <beamlit.types.Unset object>, token_total: beamlit.types.Unset | float = <beamlit.types.Unset object>, trend: beamlit.types.Unset | float = <beamlit.types.Unset object>)`
:   Token rate metric
    
    Attributes:
        model (Union[Unset, str]): Model ID
        timestamp (Union[Unset, str]): Timestamp
        token_total (Union[Unset, float]): Total tokens
        trend (Union[Unset, float]): Trend
    
    Method generated by attrs for class TokenRateMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `model: beamlit.types.Unset | str`
    :

    `timestamp: beamlit.types.Unset | str`
    :

    `token_total: beamlit.types.Unset | float`
    :

    `trend: beamlit.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :